# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ogoutils']

package_data = \
{'': ['*']}

install_requires = \
['pyAesCrypt>=6.0.0,<7.0.0', 'pytest>=7.1.3,<8.0.0']

entry_points = \
{'console_scripts': ['ogoutils = ogoutils.__main__:main']}

setup_kwargs = {
    'name': 'ogo-utils',
    'version': '0.1.13',
    'description': 'This project prefer utils for self working',
    'long_description': '# OGO Clients Utils | Python == 3.9.10\n\n> This project provides utilities for my daily use.\n\n## Installation\n\n```shell\npython3 -m pip install ogo-utils\n```\n\n## Set config\n```shell\npoetry config pypi-token.pypi pypi-token\n```',
    'author': 'Vasiliy Silver',
    'author_email': 's555133@mail.ru',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



import os
from datetime import datetime
from pathlib import Path

from ogoutils.encryption import encryption
from ogoutils.decryption import decryption

pwd = Path.cwd()

file_path = str(pwd / 'diary')
crp_file_path = str(pwd / 'diary.crp')

def write_diary():
    """ Write your thoughts into the diary file """
    password = input('Введите пароль: ')

    with open(file_path, 'a+') as f:
        note = input('OGO-DIARY: Привет! Напиши о чем думаешь:\n>>>')
        f.write(f'{datetime.now().isoformat()}\n{note}\n\n')

    with open(file_path, 'r') as f:
        print(f.read())

    encryption(file=file_path, password=password)


def read_diary():
    password = input('Введите пароль: ')
    decryption(file=crp_file_path, password=password)
    with open(file_path, 'r') as f:
        print(f.read())


if __name__ == "__main__":
    write_diary()
    read_diary()



import traceback

import pyAesCrypt
import os


def decryption(file, password) -> None:
    """
    Функция для дешифрования файла
    :rtype: None
    """

    buffer_size = 512 * 1024

    pyAesCrypt.decryptFile(
        str(file),
        str(os.path.splitext(file)[0]),
        password,
        buffer_size
    )

    # Имя зашифрованного файла
    print(f'[Файл {str(os.path.splitext(file)[0])} - дешифрован')

    # удалим исходный файл
    os.remove(file)


def walk_to_decrypt(directory: str, passwd: str) -> None:
    """
    Функция сканирования директорий
    :type passwd: str
    :param directory: директория которую сканируем
    :param passwd: пароль
    """
    for name in os.listdir(directory):
        path = os.path.join(directory, name)

        if os.path.isfile(path):

            try:
                decryption(path, passwd)
            except Exception as ex:
                traceback.print_exc(ex)

        else:
            walk_to_decrypt(path, passwd)


if __name__ == '__main__':
    password = input('Введите пароль для расшифровки: ')
    dir_to_decrypt = input('Введите дирректорию которую хотите расшифровать')
    walk_to_decrypt(dir_to_decrypt, password)
